// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.240111.5

#pragma once
#ifndef WINRT_Microsoft_UI_Xaml_Controls_1_H
#define WINRT_Microsoft_UI_Xaml_Controls_1_H
#include "winrt/impl/Windows.Foundation.0.h"
#include "winrt/impl/Microsoft.UI.Xaml.Controls.0.h"
WINRT_EXPORT namespace winrt::Microsoft::UI::Xaml::Controls
{
    struct WINRT_IMPL_EMPTY_BASES IAnimatedIcon :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAnimatedIcon>
    {
        IAnimatedIcon(std::nullptr_t = nullptr) noexcept {}
        IAnimatedIcon(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAnimatedIconFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAnimatedIconFactory>
    {
        IAnimatedIconFactory(std::nullptr_t = nullptr) noexcept {}
        IAnimatedIconFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAnimatedIconSource :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAnimatedIconSource>
    {
        IAnimatedIconSource(std::nullptr_t = nullptr) noexcept {}
        IAnimatedIconSource(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAnimatedIconSourceFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAnimatedIconSourceFactory>
    {
        IAnimatedIconSourceFactory(std::nullptr_t = nullptr) noexcept {}
        IAnimatedIconSourceFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAnimatedIconSourceStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAnimatedIconSourceStatics>
    {
        IAnimatedIconSourceStatics(std::nullptr_t = nullptr) noexcept {}
        IAnimatedIconSourceStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAnimatedIconStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAnimatedIconStatics>
    {
        IAnimatedIconStatics(std::nullptr_t = nullptr) noexcept {}
        IAnimatedIconStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAnimatedVisual :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAnimatedVisual>,
        impl::require<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisual, winrt::Windows::Foundation::IClosable>
    {
        IAnimatedVisual(std::nullptr_t = nullptr) noexcept {}
        IAnimatedVisual(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAnimatedVisual2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAnimatedVisual2>,
        impl::require<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisual2, winrt::Windows::Foundation::IClosable, winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisual>
    {
        IAnimatedVisual2(std::nullptr_t = nullptr) noexcept {}
        IAnimatedVisual2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAnimatedVisualPlayer :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAnimatedVisualPlayer>
    {
        IAnimatedVisualPlayer(std::nullptr_t = nullptr) noexcept {}
        IAnimatedVisualPlayer(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAnimatedVisualPlayer2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAnimatedVisualPlayer2>
    {
        IAnimatedVisualPlayer2(std::nullptr_t = nullptr) noexcept {}
        IAnimatedVisualPlayer2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAnimatedVisualPlayerFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAnimatedVisualPlayerFactory>
    {
        IAnimatedVisualPlayerFactory(std::nullptr_t = nullptr) noexcept {}
        IAnimatedVisualPlayerFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAnimatedVisualPlayerStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAnimatedVisualPlayerStatics>
    {
        IAnimatedVisualPlayerStatics(std::nullptr_t = nullptr) noexcept {}
        IAnimatedVisualPlayerStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAnimatedVisualPlayerStatics2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAnimatedVisualPlayerStatics2>
    {
        IAnimatedVisualPlayerStatics2(std::nullptr_t = nullptr) noexcept {}
        IAnimatedVisualPlayerStatics2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAnimatedVisualSource :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAnimatedVisualSource>
    {
        IAnimatedVisualSource(std::nullptr_t = nullptr) noexcept {}
        IAnimatedVisualSource(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAnimatedVisualSource2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAnimatedVisualSource2>,
        impl::require<winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource2, winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource>
    {
        IAnimatedVisualSource2(std::nullptr_t = nullptr) noexcept {}
        IAnimatedVisualSource2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAnimatedVisualSource3 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAnimatedVisualSource3>
    {
        IAnimatedVisualSource3(std::nullptr_t = nullptr) noexcept {}
        IAnimatedVisualSource3(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IBackdropMaterial :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IBackdropMaterial>
    {
        IBackdropMaterial(std::nullptr_t = nullptr) noexcept {}
        IBackdropMaterial(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IBackdropMaterialFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IBackdropMaterialFactory>
    {
        IBackdropMaterialFactory(std::nullptr_t = nullptr) noexcept {}
        IBackdropMaterialFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IBackdropMaterialStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IBackdropMaterialStatics>
    {
        IBackdropMaterialStatics(std::nullptr_t = nullptr) noexcept {}
        IBackdropMaterialStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IBitmapIconSource :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IBitmapIconSource>
    {
        IBitmapIconSource(std::nullptr_t = nullptr) noexcept {}
        IBitmapIconSource(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IBitmapIconSourceFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IBitmapIconSourceFactory>
    {
        IBitmapIconSourceFactory(std::nullptr_t = nullptr) noexcept {}
        IBitmapIconSourceFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IBitmapIconSourceStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IBitmapIconSourceStatics>
    {
        IBitmapIconSourceStatics(std::nullptr_t = nullptr) noexcept {}
        IBitmapIconSourceStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IBreadcrumbBar :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IBreadcrumbBar>
    {
        IBreadcrumbBar(std::nullptr_t = nullptr) noexcept {}
        IBreadcrumbBar(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IBreadcrumbBarFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IBreadcrumbBarFactory>
    {
        IBreadcrumbBarFactory(std::nullptr_t = nullptr) noexcept {}
        IBreadcrumbBarFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IBreadcrumbBarItem :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IBreadcrumbBarItem>
    {
        IBreadcrumbBarItem(std::nullptr_t = nullptr) noexcept {}
        IBreadcrumbBarItem(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IBreadcrumbBarItemClickedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IBreadcrumbBarItemClickedEventArgs>
    {
        IBreadcrumbBarItemClickedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IBreadcrumbBarItemClickedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IBreadcrumbBarItemFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IBreadcrumbBarItemFactory>
    {
        IBreadcrumbBarItemFactory(std::nullptr_t = nullptr) noexcept {}
        IBreadcrumbBarItemFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IBreadcrumbBarStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IBreadcrumbBarStatics>
    {
        IBreadcrumbBarStatics(std::nullptr_t = nullptr) noexcept {}
        IBreadcrumbBarStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IColorChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IColorChangedEventArgs>
    {
        IColorChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IColorChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IColorPicker :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IColorPicker>
    {
        IColorPicker(std::nullptr_t = nullptr) noexcept {}
        IColorPicker(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IColorPicker2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IColorPicker2>
    {
        IColorPicker2(std::nullptr_t = nullptr) noexcept {}
        IColorPicker2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IColorPickerFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IColorPickerFactory>
    {
        IColorPickerFactory(std::nullptr_t = nullptr) noexcept {}
        IColorPickerFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IColorPickerStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IColorPickerStatics>
    {
        IColorPickerStatics(std::nullptr_t = nullptr) noexcept {}
        IColorPickerStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IColorPickerStatics2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IColorPickerStatics2>
    {
        IColorPickerStatics2(std::nullptr_t = nullptr) noexcept {}
        IColorPickerStatics2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ICommandBarFlyout :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ICommandBarFlyout>
    {
        ICommandBarFlyout(std::nullptr_t = nullptr) noexcept {}
        ICommandBarFlyout(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ICommandBarFlyout2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ICommandBarFlyout2>
    {
        ICommandBarFlyout2(std::nullptr_t = nullptr) noexcept {}
        ICommandBarFlyout2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ICommandBarFlyoutFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ICommandBarFlyoutFactory>
    {
        ICommandBarFlyoutFactory(std::nullptr_t = nullptr) noexcept {}
        ICommandBarFlyoutFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ICoreWebView2InitializedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ICoreWebView2InitializedEventArgs>
    {
        ICoreWebView2InitializedEventArgs(std::nullptr_t = nullptr) noexcept {}
        ICoreWebView2InitializedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IDropDownButton :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IDropDownButton>
    {
        IDropDownButton(std::nullptr_t = nullptr) noexcept {}
        IDropDownButton(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IDropDownButtonFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IDropDownButtonFactory>
    {
        IDropDownButtonFactory(std::nullptr_t = nullptr) noexcept {}
        IDropDownButtonFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IDynamicAnimatedVisualSource :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IDynamicAnimatedVisualSource>,
        impl::require<winrt::Microsoft::UI::Xaml::Controls::IDynamicAnimatedVisualSource, winrt::Microsoft::UI::Xaml::Controls::IAnimatedVisualSource>
    {
        IDynamicAnimatedVisualSource(std::nullptr_t = nullptr) noexcept {}
        IDynamicAnimatedVisualSource(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IElementFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IElementFactory>
    {
        IElementFactory(std::nullptr_t = nullptr) noexcept {}
        IElementFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IElementFactoryFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IElementFactoryFactory>
    {
        IElementFactoryFactory(std::nullptr_t = nullptr) noexcept {}
        IElementFactoryFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IElementFactoryGetArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IElementFactoryGetArgs>
    {
        IElementFactoryGetArgs(std::nullptr_t = nullptr) noexcept {}
        IElementFactoryGetArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IElementFactoryOverrides :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IElementFactoryOverrides>
    {
        IElementFactoryOverrides(std::nullptr_t = nullptr) noexcept {}
        IElementFactoryOverrides(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IElementFactoryRecycleArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IElementFactoryRecycleArgs>
    {
        IElementFactoryRecycleArgs(std::nullptr_t = nullptr) noexcept {}
        IElementFactoryRecycleArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IExpander :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IExpander>
    {
        IExpander(std::nullptr_t = nullptr) noexcept {}
        IExpander(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IExpanderCollapsedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IExpanderCollapsedEventArgs>
    {
        IExpanderCollapsedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IExpanderCollapsedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IExpanderExpandingEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IExpanderExpandingEventArgs>
    {
        IExpanderExpandingEventArgs(std::nullptr_t = nullptr) noexcept {}
        IExpanderExpandingEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IExpanderFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IExpanderFactory>
    {
        IExpanderFactory(std::nullptr_t = nullptr) noexcept {}
        IExpanderFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IExpanderStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IExpanderStatics>
    {
        IExpanderStatics(std::nullptr_t = nullptr) noexcept {}
        IExpanderStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IExpanderTemplateSettings :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IExpanderTemplateSettings>
    {
        IExpanderTemplateSettings(std::nullptr_t = nullptr) noexcept {}
        IExpanderTemplateSettings(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IFontIconSource :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IFontIconSource>
    {
        IFontIconSource(std::nullptr_t = nullptr) noexcept {}
        IFontIconSource(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IFontIconSourceFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IFontIconSourceFactory>
    {
        IFontIconSourceFactory(std::nullptr_t = nullptr) noexcept {}
        IFontIconSourceFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IFontIconSourceStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IFontIconSourceStatics>
    {
        IFontIconSourceStatics(std::nullptr_t = nullptr) noexcept {}
        IFontIconSourceStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IIconSource :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IIconSource>
    {
        IIconSource(std::nullptr_t = nullptr) noexcept {}
        IIconSource(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IIconSourceFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IIconSourceFactory>
    {
        IIconSourceFactory(std::nullptr_t = nullptr) noexcept {}
        IIconSourceFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IIconSourceStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IIconSourceStatics>
    {
        IIconSourceStatics(std::nullptr_t = nullptr) noexcept {}
        IIconSourceStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IImageIcon :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IImageIcon>
    {
        IImageIcon(std::nullptr_t = nullptr) noexcept {}
        IImageIcon(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IImageIconFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IImageIconFactory>
    {
        IImageIconFactory(std::nullptr_t = nullptr) noexcept {}
        IImageIconFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IImageIconSource :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IImageIconSource>
    {
        IImageIconSource(std::nullptr_t = nullptr) noexcept {}
        IImageIconSource(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IImageIconSourceFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IImageIconSourceFactory>
    {
        IImageIconSourceFactory(std::nullptr_t = nullptr) noexcept {}
        IImageIconSourceFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IImageIconSourceStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IImageIconSourceStatics>
    {
        IImageIconSourceStatics(std::nullptr_t = nullptr) noexcept {}
        IImageIconSourceStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IImageIconStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IImageIconStatics>
    {
        IImageIconStatics(std::nullptr_t = nullptr) noexcept {}
        IImageIconStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IInfoBadge :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IInfoBadge>
    {
        IInfoBadge(std::nullptr_t = nullptr) noexcept {}
        IInfoBadge(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IInfoBadgeFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IInfoBadgeFactory>
    {
        IInfoBadgeFactory(std::nullptr_t = nullptr) noexcept {}
        IInfoBadgeFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IInfoBadgeStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IInfoBadgeStatics>
    {
        IInfoBadgeStatics(std::nullptr_t = nullptr) noexcept {}
        IInfoBadgeStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IInfoBadgeTemplateSettings :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IInfoBadgeTemplateSettings>
    {
        IInfoBadgeTemplateSettings(std::nullptr_t = nullptr) noexcept {}
        IInfoBadgeTemplateSettings(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IInfoBadgeTemplateSettingsFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IInfoBadgeTemplateSettingsFactory>
    {
        IInfoBadgeTemplateSettingsFactory(std::nullptr_t = nullptr) noexcept {}
        IInfoBadgeTemplateSettingsFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IInfoBadgeTemplateSettingsStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IInfoBadgeTemplateSettingsStatics>
    {
        IInfoBadgeTemplateSettingsStatics(std::nullptr_t = nullptr) noexcept {}
        IInfoBadgeTemplateSettingsStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IInfoBar :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IInfoBar>
    {
        IInfoBar(std::nullptr_t = nullptr) noexcept {}
        IInfoBar(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IInfoBarClosedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IInfoBarClosedEventArgs>
    {
        IInfoBarClosedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IInfoBarClosedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IInfoBarClosedEventArgsFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IInfoBarClosedEventArgsFactory>
    {
        IInfoBarClosedEventArgsFactory(std::nullptr_t = nullptr) noexcept {}
        IInfoBarClosedEventArgsFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IInfoBarClosingEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IInfoBarClosingEventArgs>
    {
        IInfoBarClosingEventArgs(std::nullptr_t = nullptr) noexcept {}
        IInfoBarClosingEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IInfoBarClosingEventArgsFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IInfoBarClosingEventArgsFactory>
    {
        IInfoBarClosingEventArgsFactory(std::nullptr_t = nullptr) noexcept {}
        IInfoBarClosingEventArgsFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IInfoBarFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IInfoBarFactory>
    {
        IInfoBarFactory(std::nullptr_t = nullptr) noexcept {}
        IInfoBarFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IInfoBarStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IInfoBarStatics>
    {
        IInfoBarStatics(std::nullptr_t = nullptr) noexcept {}
        IInfoBarStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IInfoBarTemplateSettings :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IInfoBarTemplateSettings>
    {
        IInfoBarTemplateSettings(std::nullptr_t = nullptr) noexcept {}
        IInfoBarTemplateSettings(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IInfoBarTemplateSettingsFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IInfoBarTemplateSettingsFactory>
    {
        IInfoBarTemplateSettingsFactory(std::nullptr_t = nullptr) noexcept {}
        IInfoBarTemplateSettingsFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IInfoBarTemplateSettingsStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IInfoBarTemplateSettingsStatics>
    {
        IInfoBarTemplateSettingsStatics(std::nullptr_t = nullptr) noexcept {}
        IInfoBarTemplateSettingsStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IItemsRepeater :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IItemsRepeater>
    {
        IItemsRepeater(std::nullptr_t = nullptr) noexcept {}
        IItemsRepeater(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IItemsRepeaterElementClearingEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IItemsRepeaterElementClearingEventArgs>
    {
        IItemsRepeaterElementClearingEventArgs(std::nullptr_t = nullptr) noexcept {}
        IItemsRepeaterElementClearingEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IItemsRepeaterElementIndexChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IItemsRepeaterElementIndexChangedEventArgs>
    {
        IItemsRepeaterElementIndexChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IItemsRepeaterElementIndexChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IItemsRepeaterElementPreparedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IItemsRepeaterElementPreparedEventArgs>
    {
        IItemsRepeaterElementPreparedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IItemsRepeaterElementPreparedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IItemsRepeaterFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IItemsRepeaterFactory>
    {
        IItemsRepeaterFactory(std::nullptr_t = nullptr) noexcept {}
        IItemsRepeaterFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IItemsRepeaterScrollHost :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IItemsRepeaterScrollHost>
    {
        IItemsRepeaterScrollHost(std::nullptr_t = nullptr) noexcept {}
        IItemsRepeaterScrollHost(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IItemsRepeaterStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IItemsRepeaterStatics>
    {
        IItemsRepeaterStatics(std::nullptr_t = nullptr) noexcept {}
        IItemsRepeaterStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IItemsSourceView :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IItemsSourceView>
    {
        IItemsSourceView(std::nullptr_t = nullptr) noexcept {}
        IItemsSourceView(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IItemsSourceViewFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IItemsSourceViewFactory>
    {
        IItemsSourceViewFactory(std::nullptr_t = nullptr) noexcept {}
        IItemsSourceViewFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IKeyIndexMapping :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IKeyIndexMapping>
    {
        IKeyIndexMapping(std::nullptr_t = nullptr) noexcept {}
        IKeyIndexMapping(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ILayout :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ILayout>
    {
        ILayout(std::nullptr_t = nullptr) noexcept {}
        ILayout(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ILayoutContext :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ILayoutContext>
    {
        ILayoutContext(std::nullptr_t = nullptr) noexcept {}
        ILayoutContext(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ILayoutContextFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ILayoutContextFactory>
    {
        ILayoutContextFactory(std::nullptr_t = nullptr) noexcept {}
        ILayoutContextFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ILayoutContextOverrides :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ILayoutContextOverrides>
    {
        ILayoutContextOverrides(std::nullptr_t = nullptr) noexcept {}
        ILayoutContextOverrides(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ILayoutFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ILayoutFactory>
    {
        ILayoutFactory(std::nullptr_t = nullptr) noexcept {}
        ILayoutFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ILayoutProtected :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ILayoutProtected>
    {
        ILayoutProtected(std::nullptr_t = nullptr) noexcept {}
        ILayoutProtected(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMenuBar :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMenuBar>
    {
        IMenuBar(std::nullptr_t = nullptr) noexcept {}
        IMenuBar(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMenuBarFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMenuBarFactory>
    {
        IMenuBarFactory(std::nullptr_t = nullptr) noexcept {}
        IMenuBarFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMenuBarItem :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMenuBarItem>
    {
        IMenuBarItem(std::nullptr_t = nullptr) noexcept {}
        IMenuBarItem(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMenuBarItemFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMenuBarItemFactory>
    {
        IMenuBarItemFactory(std::nullptr_t = nullptr) noexcept {}
        IMenuBarItemFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMenuBarItemFlyout :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMenuBarItemFlyout>
    {
        IMenuBarItemFlyout(std::nullptr_t = nullptr) noexcept {}
        IMenuBarItemFlyout(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMenuBarItemFlyoutFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMenuBarItemFlyoutFactory>
    {
        IMenuBarItemFlyoutFactory(std::nullptr_t = nullptr) noexcept {}
        IMenuBarItemFlyoutFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMenuBarItemStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMenuBarItemStatics>
    {
        IMenuBarItemStatics(std::nullptr_t = nullptr) noexcept {}
        IMenuBarItemStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IMenuBarStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IMenuBarStatics>
    {
        IMenuBarStatics(std::nullptr_t = nullptr) noexcept {}
        IMenuBarStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationView :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationView>
    {
        INavigationView(std::nullptr_t = nullptr) noexcept {}
        INavigationView(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationView2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationView2>
    {
        INavigationView2(std::nullptr_t = nullptr) noexcept {}
        INavigationView2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewBackRequestedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewBackRequestedEventArgs>
    {
        INavigationViewBackRequestedEventArgs(std::nullptr_t = nullptr) noexcept {}
        INavigationViewBackRequestedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewDisplayModeChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewDisplayModeChangedEventArgs>
    {
        INavigationViewDisplayModeChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        INavigationViewDisplayModeChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewFactory>
    {
        INavigationViewFactory(std::nullptr_t = nullptr) noexcept {}
        INavigationViewFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewItem :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewItem>
    {
        INavigationViewItem(std::nullptr_t = nullptr) noexcept {}
        INavigationViewItem(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewItem2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewItem2>
    {
        INavigationViewItem2(std::nullptr_t = nullptr) noexcept {}
        INavigationViewItem2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewItem3 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewItem3>
    {
        INavigationViewItem3(std::nullptr_t = nullptr) noexcept {}
        INavigationViewItem3(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewItemBase :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewItemBase>
    {
        INavigationViewItemBase(std::nullptr_t = nullptr) noexcept {}
        INavigationViewItemBase(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewItemBase2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewItemBase2>
    {
        INavigationViewItemBase2(std::nullptr_t = nullptr) noexcept {}
        INavigationViewItemBase2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewItemBaseFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewItemBaseFactory>
    {
        INavigationViewItemBaseFactory(std::nullptr_t = nullptr) noexcept {}
        INavigationViewItemBaseFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewItemBaseStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewItemBaseStatics>
    {
        INavigationViewItemBaseStatics(std::nullptr_t = nullptr) noexcept {}
        INavigationViewItemBaseStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewItemCollapsedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewItemCollapsedEventArgs>
    {
        INavigationViewItemCollapsedEventArgs(std::nullptr_t = nullptr) noexcept {}
        INavigationViewItemCollapsedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewItemExpandingEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewItemExpandingEventArgs>
    {
        INavigationViewItemExpandingEventArgs(std::nullptr_t = nullptr) noexcept {}
        INavigationViewItemExpandingEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewItemFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewItemFactory>
    {
        INavigationViewItemFactory(std::nullptr_t = nullptr) noexcept {}
        INavigationViewItemFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewItemHeader :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewItemHeader>
    {
        INavigationViewItemHeader(std::nullptr_t = nullptr) noexcept {}
        INavigationViewItemHeader(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewItemHeaderFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewItemHeaderFactory>
    {
        INavigationViewItemHeaderFactory(std::nullptr_t = nullptr) noexcept {}
        INavigationViewItemHeaderFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewItemInvokedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewItemInvokedEventArgs>
    {
        INavigationViewItemInvokedEventArgs(std::nullptr_t = nullptr) noexcept {}
        INavigationViewItemInvokedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewItemInvokedEventArgs2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewItemInvokedEventArgs2>
    {
        INavigationViewItemInvokedEventArgs2(std::nullptr_t = nullptr) noexcept {}
        INavigationViewItemInvokedEventArgs2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewItemSeparator :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewItemSeparator>
    {
        INavigationViewItemSeparator(std::nullptr_t = nullptr) noexcept {}
        INavigationViewItemSeparator(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewItemSeparatorFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewItemSeparatorFactory>
    {
        INavigationViewItemSeparatorFactory(std::nullptr_t = nullptr) noexcept {}
        INavigationViewItemSeparatorFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewItemStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewItemStatics>
    {
        INavigationViewItemStatics(std::nullptr_t = nullptr) noexcept {}
        INavigationViewItemStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewItemStatics2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewItemStatics2>
    {
        INavigationViewItemStatics2(std::nullptr_t = nullptr) noexcept {}
        INavigationViewItemStatics2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewItemStatics3 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewItemStatics3>
    {
        INavigationViewItemStatics3(std::nullptr_t = nullptr) noexcept {}
        INavigationViewItemStatics3(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewPaneClosingEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewPaneClosingEventArgs>
    {
        INavigationViewPaneClosingEventArgs(std::nullptr_t = nullptr) noexcept {}
        INavigationViewPaneClosingEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewSelectionChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewSelectionChangedEventArgs>
    {
        INavigationViewSelectionChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        INavigationViewSelectionChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewSelectionChangedEventArgs2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewSelectionChangedEventArgs2>
    {
        INavigationViewSelectionChangedEventArgs2(std::nullptr_t = nullptr) noexcept {}
        INavigationViewSelectionChangedEventArgs2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewStatics>
    {
        INavigationViewStatics(std::nullptr_t = nullptr) noexcept {}
        INavigationViewStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewStatics2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewStatics2>
    {
        INavigationViewStatics2(std::nullptr_t = nullptr) noexcept {}
        INavigationViewStatics2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewTemplateSettings :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewTemplateSettings>
    {
        INavigationViewTemplateSettings(std::nullptr_t = nullptr) noexcept {}
        INavigationViewTemplateSettings(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewTemplateSettings2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewTemplateSettings2>
    {
        INavigationViewTemplateSettings2(std::nullptr_t = nullptr) noexcept {}
        INavigationViewTemplateSettings2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewTemplateSettingsFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewTemplateSettingsFactory>
    {
        INavigationViewTemplateSettingsFactory(std::nullptr_t = nullptr) noexcept {}
        INavigationViewTemplateSettingsFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewTemplateSettingsStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewTemplateSettingsStatics>
    {
        INavigationViewTemplateSettingsStatics(std::nullptr_t = nullptr) noexcept {}
        INavigationViewTemplateSettingsStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INavigationViewTemplateSettingsStatics2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INavigationViewTemplateSettingsStatics2>
    {
        INavigationViewTemplateSettingsStatics2(std::nullptr_t = nullptr) noexcept {}
        INavigationViewTemplateSettingsStatics2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INonVirtualizingLayout :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INonVirtualizingLayout>
    {
        INonVirtualizingLayout(std::nullptr_t = nullptr) noexcept {}
        INonVirtualizingLayout(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INonVirtualizingLayoutContext :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INonVirtualizingLayoutContext>
    {
        INonVirtualizingLayoutContext(std::nullptr_t = nullptr) noexcept {}
        INonVirtualizingLayoutContext(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INonVirtualizingLayoutContextFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INonVirtualizingLayoutContextFactory>
    {
        INonVirtualizingLayoutContextFactory(std::nullptr_t = nullptr) noexcept {}
        INonVirtualizingLayoutContextFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INonVirtualizingLayoutContextOverrides :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INonVirtualizingLayoutContextOverrides>
    {
        INonVirtualizingLayoutContextOverrides(std::nullptr_t = nullptr) noexcept {}
        INonVirtualizingLayoutContextOverrides(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INonVirtualizingLayoutFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INonVirtualizingLayoutFactory>
    {
        INonVirtualizingLayoutFactory(std::nullptr_t = nullptr) noexcept {}
        INonVirtualizingLayoutFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INonVirtualizingLayoutOverrides :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INonVirtualizingLayoutOverrides>
    {
        INonVirtualizingLayoutOverrides(std::nullptr_t = nullptr) noexcept {}
        INonVirtualizingLayoutOverrides(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INumberBox :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INumberBox>
    {
        INumberBox(std::nullptr_t = nullptr) noexcept {}
        INumberBox(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INumberBoxFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INumberBoxFactory>
    {
        INumberBoxFactory(std::nullptr_t = nullptr) noexcept {}
        INumberBoxFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INumberBoxStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INumberBoxStatics>
    {
        INumberBoxStatics(std::nullptr_t = nullptr) noexcept {}
        INumberBoxStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES INumberBoxValueChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<INumberBoxValueChangedEventArgs>
    {
        INumberBoxValueChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        INumberBoxValueChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IParallaxView :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IParallaxView>
    {
        IParallaxView(std::nullptr_t = nullptr) noexcept {}
        IParallaxView(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IParallaxViewFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IParallaxViewFactory>
    {
        IParallaxViewFactory(std::nullptr_t = nullptr) noexcept {}
        IParallaxViewFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IParallaxViewStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IParallaxViewStatics>
    {
        IParallaxViewStatics(std::nullptr_t = nullptr) noexcept {}
        IParallaxViewStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPathIconSource :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPathIconSource>
    {
        IPathIconSource(std::nullptr_t = nullptr) noexcept {}
        IPathIconSource(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPathIconSourceFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPathIconSourceFactory>
    {
        IPathIconSourceFactory(std::nullptr_t = nullptr) noexcept {}
        IPathIconSourceFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPathIconSourceStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPathIconSourceStatics>
    {
        IPathIconSourceStatics(std::nullptr_t = nullptr) noexcept {}
        IPathIconSourceStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPersonPicture :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPersonPicture>
    {
        IPersonPicture(std::nullptr_t = nullptr) noexcept {}
        IPersonPicture(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPersonPictureFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPersonPictureFactory>
    {
        IPersonPictureFactory(std::nullptr_t = nullptr) noexcept {}
        IPersonPictureFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPersonPictureStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPersonPictureStatics>
    {
        IPersonPictureStatics(std::nullptr_t = nullptr) noexcept {}
        IPersonPictureStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPersonPictureTemplateSettings :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPersonPictureTemplateSettings>
    {
        IPersonPictureTemplateSettings(std::nullptr_t = nullptr) noexcept {}
        IPersonPictureTemplateSettings(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPipsPager :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPipsPager>
    {
        IPipsPager(std::nullptr_t = nullptr) noexcept {}
        IPipsPager(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPipsPagerFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPipsPagerFactory>
    {
        IPipsPagerFactory(std::nullptr_t = nullptr) noexcept {}
        IPipsPagerFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPipsPagerSelectedIndexChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPipsPagerSelectedIndexChangedEventArgs>
    {
        IPipsPagerSelectedIndexChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IPipsPagerSelectedIndexChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPipsPagerStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPipsPagerStatics>
    {
        IPipsPagerStatics(std::nullptr_t = nullptr) noexcept {}
        IPipsPagerStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPipsPagerTemplateSettings :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPipsPagerTemplateSettings>
    {
        IPipsPagerTemplateSettings(std::nullptr_t = nullptr) noexcept {}
        IPipsPagerTemplateSettings(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IProgressBar :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IProgressBar>
    {
        IProgressBar(std::nullptr_t = nullptr) noexcept {}
        IProgressBar(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IProgressBarFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IProgressBarFactory>
    {
        IProgressBarFactory(std::nullptr_t = nullptr) noexcept {}
        IProgressBarFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IProgressBarStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IProgressBarStatics>
    {
        IProgressBarStatics(std::nullptr_t = nullptr) noexcept {}
        IProgressBarStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IProgressBarTemplateSettings :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IProgressBarTemplateSettings>
    {
        IProgressBarTemplateSettings(std::nullptr_t = nullptr) noexcept {}
        IProgressBarTemplateSettings(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IProgressRing :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IProgressRing>
    {
        IProgressRing(std::nullptr_t = nullptr) noexcept {}
        IProgressRing(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IProgressRingFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IProgressRingFactory>
    {
        IProgressRingFactory(std::nullptr_t = nullptr) noexcept {}
        IProgressRingFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IProgressRingStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IProgressRingStatics>
    {
        IProgressRingStatics(std::nullptr_t = nullptr) noexcept {}
        IProgressRingStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IProgressRingTemplateSettings :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IProgressRingTemplateSettings>
    {
        IProgressRingTemplateSettings(std::nullptr_t = nullptr) noexcept {}
        IProgressRingTemplateSettings(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRadioButtons :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRadioButtons>
    {
        IRadioButtons(std::nullptr_t = nullptr) noexcept {}
        IRadioButtons(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRadioButtonsFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRadioButtonsFactory>
    {
        IRadioButtonsFactory(std::nullptr_t = nullptr) noexcept {}
        IRadioButtonsFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRadioButtonsStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRadioButtonsStatics>
    {
        IRadioButtonsStatics(std::nullptr_t = nullptr) noexcept {}
        IRadioButtonsStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRadioMenuFlyoutItem :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRadioMenuFlyoutItem>
    {
        IRadioMenuFlyoutItem(std::nullptr_t = nullptr) noexcept {}
        IRadioMenuFlyoutItem(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRadioMenuFlyoutItemFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRadioMenuFlyoutItemFactory>
    {
        IRadioMenuFlyoutItemFactory(std::nullptr_t = nullptr) noexcept {}
        IRadioMenuFlyoutItemFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRadioMenuFlyoutItemStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRadioMenuFlyoutItemStatics>
    {
        IRadioMenuFlyoutItemStatics(std::nullptr_t = nullptr) noexcept {}
        IRadioMenuFlyoutItemStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRadioMenuFlyoutItemStatics2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRadioMenuFlyoutItemStatics2>
    {
        IRadioMenuFlyoutItemStatics2(std::nullptr_t = nullptr) noexcept {}
        IRadioMenuFlyoutItemStatics2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRatingControl :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRatingControl>
    {
        IRatingControl(std::nullptr_t = nullptr) noexcept {}
        IRatingControl(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRatingControlFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRatingControlFactory>
    {
        IRatingControlFactory(std::nullptr_t = nullptr) noexcept {}
        IRatingControlFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRatingControlStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRatingControlStatics>
    {
        IRatingControlStatics(std::nullptr_t = nullptr) noexcept {}
        IRatingControlStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRatingItemFontInfo :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRatingItemFontInfo>
    {
        IRatingItemFontInfo(std::nullptr_t = nullptr) noexcept {}
        IRatingItemFontInfo(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRatingItemFontInfoFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRatingItemFontInfoFactory>
    {
        IRatingItemFontInfoFactory(std::nullptr_t = nullptr) noexcept {}
        IRatingItemFontInfoFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRatingItemFontInfoStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRatingItemFontInfoStatics>
    {
        IRatingItemFontInfoStatics(std::nullptr_t = nullptr) noexcept {}
        IRatingItemFontInfoStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRatingItemImageInfo :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRatingItemImageInfo>
    {
        IRatingItemImageInfo(std::nullptr_t = nullptr) noexcept {}
        IRatingItemImageInfo(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRatingItemImageInfoFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRatingItemImageInfoFactory>
    {
        IRatingItemImageInfoFactory(std::nullptr_t = nullptr) noexcept {}
        IRatingItemImageInfoFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRatingItemImageInfoStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRatingItemImageInfoStatics>
    {
        IRatingItemImageInfoStatics(std::nullptr_t = nullptr) noexcept {}
        IRatingItemImageInfoStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRatingItemInfo :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRatingItemInfo>
    {
        IRatingItemInfo(std::nullptr_t = nullptr) noexcept {}
        IRatingItemInfo(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRatingItemInfoFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRatingItemInfoFactory>
    {
        IRatingItemInfoFactory(std::nullptr_t = nullptr) noexcept {}
        IRatingItemInfoFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRefreshContainer :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRefreshContainer>
    {
        IRefreshContainer(std::nullptr_t = nullptr) noexcept {}
        IRefreshContainer(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRefreshContainerFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRefreshContainerFactory>
    {
        IRefreshContainerFactory(std::nullptr_t = nullptr) noexcept {}
        IRefreshContainerFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRefreshContainerStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRefreshContainerStatics>
    {
        IRefreshContainerStatics(std::nullptr_t = nullptr) noexcept {}
        IRefreshContainerStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRefreshInteractionRatioChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRefreshInteractionRatioChangedEventArgs>
    {
        IRefreshInteractionRatioChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IRefreshInteractionRatioChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRefreshRequestedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRefreshRequestedEventArgs>
    {
        IRefreshRequestedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IRefreshRequestedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRefreshStateChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRefreshStateChangedEventArgs>
    {
        IRefreshStateChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IRefreshStateChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRefreshVisualizer :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRefreshVisualizer>
    {
        IRefreshVisualizer(std::nullptr_t = nullptr) noexcept {}
        IRefreshVisualizer(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRefreshVisualizerFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRefreshVisualizerFactory>
    {
        IRefreshVisualizerFactory(std::nullptr_t = nullptr) noexcept {}
        IRefreshVisualizerFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRefreshVisualizerStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRefreshVisualizerStatics>
    {
        IRefreshVisualizerStatics(std::nullptr_t = nullptr) noexcept {}
        IRefreshVisualizerStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRevealListViewItemPresenter :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRevealListViewItemPresenter>
    {
        IRevealListViewItemPresenter(std::nullptr_t = nullptr) noexcept {}
        IRevealListViewItemPresenter(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRevealListViewItemPresenterFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRevealListViewItemPresenterFactory>
    {
        IRevealListViewItemPresenterFactory(std::nullptr_t = nullptr) noexcept {}
        IRevealListViewItemPresenterFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISplitButton :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISplitButton>
    {
        ISplitButton(std::nullptr_t = nullptr) noexcept {}
        ISplitButton(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISplitButtonClickEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISplitButtonClickEventArgs>
    {
        ISplitButtonClickEventArgs(std::nullptr_t = nullptr) noexcept {}
        ISplitButtonClickEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISplitButtonFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISplitButtonFactory>
    {
        ISplitButtonFactory(std::nullptr_t = nullptr) noexcept {}
        ISplitButtonFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISplitButtonStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISplitButtonStatics>
    {
        ISplitButtonStatics(std::nullptr_t = nullptr) noexcept {}
        ISplitButtonStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IStackLayout :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IStackLayout>
    {
        IStackLayout(std::nullptr_t = nullptr) noexcept {}
        IStackLayout(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IStackLayoutFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IStackLayoutFactory>
    {
        IStackLayoutFactory(std::nullptr_t = nullptr) noexcept {}
        IStackLayoutFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IStackLayoutStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IStackLayoutStatics>
    {
        IStackLayoutStatics(std::nullptr_t = nullptr) noexcept {}
        IStackLayoutStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISwipeControl :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISwipeControl>
    {
        ISwipeControl(std::nullptr_t = nullptr) noexcept {}
        ISwipeControl(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISwipeControlFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISwipeControlFactory>
    {
        ISwipeControlFactory(std::nullptr_t = nullptr) noexcept {}
        ISwipeControlFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISwipeControlStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISwipeControlStatics>
    {
        ISwipeControlStatics(std::nullptr_t = nullptr) noexcept {}
        ISwipeControlStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISwipeItem :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISwipeItem>
    {
        ISwipeItem(std::nullptr_t = nullptr) noexcept {}
        ISwipeItem(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISwipeItemFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISwipeItemFactory>
    {
        ISwipeItemFactory(std::nullptr_t = nullptr) noexcept {}
        ISwipeItemFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISwipeItemInvokedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISwipeItemInvokedEventArgs>
    {
        ISwipeItemInvokedEventArgs(std::nullptr_t = nullptr) noexcept {}
        ISwipeItemInvokedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISwipeItemStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISwipeItemStatics>
    {
        ISwipeItemStatics(std::nullptr_t = nullptr) noexcept {}
        ISwipeItemStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISwipeItems :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISwipeItems>
    {
        ISwipeItems(std::nullptr_t = nullptr) noexcept {}
        ISwipeItems(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISwipeItemsFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISwipeItemsFactory>
    {
        ISwipeItemsFactory(std::nullptr_t = nullptr) noexcept {}
        ISwipeItemsFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISwipeItemsStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISwipeItemsStatics>
    {
        ISwipeItemsStatics(std::nullptr_t = nullptr) noexcept {}
        ISwipeItemsStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISymbolIconSource :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISymbolIconSource>
    {
        ISymbolIconSource(std::nullptr_t = nullptr) noexcept {}
        ISymbolIconSource(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISymbolIconSourceFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISymbolIconSourceFactory>
    {
        ISymbolIconSourceFactory(std::nullptr_t = nullptr) noexcept {}
        ISymbolIconSourceFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISymbolIconSourceStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISymbolIconSourceStatics>
    {
        ISymbolIconSourceStatics(std::nullptr_t = nullptr) noexcept {}
        ISymbolIconSourceStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITabView :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITabView>
    {
        ITabView(std::nullptr_t = nullptr) noexcept {}
        ITabView(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITabViewFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITabViewFactory>
    {
        ITabViewFactory(std::nullptr_t = nullptr) noexcept {}
        ITabViewFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITabViewItem :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITabViewItem>
    {
        ITabViewItem(std::nullptr_t = nullptr) noexcept {}
        ITabViewItem(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITabViewItemFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITabViewItemFactory>
    {
        ITabViewItemFactory(std::nullptr_t = nullptr) noexcept {}
        ITabViewItemFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITabViewItemStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITabViewItemStatics>
    {
        ITabViewItemStatics(std::nullptr_t = nullptr) noexcept {}
        ITabViewItemStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITabViewItemTemplateSettings :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITabViewItemTemplateSettings>
    {
        ITabViewItemTemplateSettings(std::nullptr_t = nullptr) noexcept {}
        ITabViewItemTemplateSettings(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITabViewItemTemplateSettings2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITabViewItemTemplateSettings2>
    {
        ITabViewItemTemplateSettings2(std::nullptr_t = nullptr) noexcept {}
        ITabViewItemTemplateSettings2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITabViewItemTemplateSettingsFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITabViewItemTemplateSettingsFactory>
    {
        ITabViewItemTemplateSettingsFactory(std::nullptr_t = nullptr) noexcept {}
        ITabViewItemTemplateSettingsFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITabViewItemTemplateSettingsStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITabViewItemTemplateSettingsStatics>
    {
        ITabViewItemTemplateSettingsStatics(std::nullptr_t = nullptr) noexcept {}
        ITabViewItemTemplateSettingsStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITabViewItemTemplateSettingsStatics2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITabViewItemTemplateSettingsStatics2>
    {
        ITabViewItemTemplateSettingsStatics2(std::nullptr_t = nullptr) noexcept {}
        ITabViewItemTemplateSettingsStatics2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITabViewStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITabViewStatics>
    {
        ITabViewStatics(std::nullptr_t = nullptr) noexcept {}
        ITabViewStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITabViewTabCloseRequestedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITabViewTabCloseRequestedEventArgs>
    {
        ITabViewTabCloseRequestedEventArgs(std::nullptr_t = nullptr) noexcept {}
        ITabViewTabCloseRequestedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITabViewTabDragCompletedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITabViewTabDragCompletedEventArgs>
    {
        ITabViewTabDragCompletedEventArgs(std::nullptr_t = nullptr) noexcept {}
        ITabViewTabDragCompletedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITabViewTabDragStartingEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITabViewTabDragStartingEventArgs>
    {
        ITabViewTabDragStartingEventArgs(std::nullptr_t = nullptr) noexcept {}
        ITabViewTabDragStartingEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITabViewTabDroppedOutsideEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITabViewTabDroppedOutsideEventArgs>
    {
        ITabViewTabDroppedOutsideEventArgs(std::nullptr_t = nullptr) noexcept {}
        ITabViewTabDroppedOutsideEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITeachingTip :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITeachingTip>
    {
        ITeachingTip(std::nullptr_t = nullptr) noexcept {}
        ITeachingTip(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITeachingTipClosedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITeachingTipClosedEventArgs>
    {
        ITeachingTipClosedEventArgs(std::nullptr_t = nullptr) noexcept {}
        ITeachingTipClosedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITeachingTipClosingEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITeachingTipClosingEventArgs>
    {
        ITeachingTipClosingEventArgs(std::nullptr_t = nullptr) noexcept {}
        ITeachingTipClosingEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITeachingTipFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITeachingTipFactory>
    {
        ITeachingTipFactory(std::nullptr_t = nullptr) noexcept {}
        ITeachingTipFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITeachingTipStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITeachingTipStatics>
    {
        ITeachingTipStatics(std::nullptr_t = nullptr) noexcept {}
        ITeachingTipStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITeachingTipTemplateSettings :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITeachingTipTemplateSettings>
    {
        ITeachingTipTemplateSettings(std::nullptr_t = nullptr) noexcept {}
        ITeachingTipTemplateSettings(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITeachingTipTemplateSettingsFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITeachingTipTemplateSettingsFactory>
    {
        ITeachingTipTemplateSettingsFactory(std::nullptr_t = nullptr) noexcept {}
        ITeachingTipTemplateSettingsFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITeachingTipTemplateSettingsStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITeachingTipTemplateSettingsStatics>
    {
        ITeachingTipTemplateSettingsStatics(std::nullptr_t = nullptr) noexcept {}
        ITeachingTipTemplateSettingsStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITextCommandBarFlyout :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITextCommandBarFlyout>
    {
        ITextCommandBarFlyout(std::nullptr_t = nullptr) noexcept {}
        ITextCommandBarFlyout(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITextCommandBarFlyoutFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITextCommandBarFlyoutFactory>
    {
        ITextCommandBarFlyoutFactory(std::nullptr_t = nullptr) noexcept {}
        ITextCommandBarFlyoutFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IToggleSplitButton :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IToggleSplitButton>
    {
        IToggleSplitButton(std::nullptr_t = nullptr) noexcept {}
        IToggleSplitButton(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IToggleSplitButtonFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IToggleSplitButtonFactory>
    {
        IToggleSplitButtonFactory(std::nullptr_t = nullptr) noexcept {}
        IToggleSplitButtonFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IToggleSplitButtonIsCheckedChangedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IToggleSplitButtonIsCheckedChangedEventArgs>
    {
        IToggleSplitButtonIsCheckedChangedEventArgs(std::nullptr_t = nullptr) noexcept {}
        IToggleSplitButtonIsCheckedChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IToggleSplitButtonStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IToggleSplitButtonStatics>
    {
        IToggleSplitButtonStatics(std::nullptr_t = nullptr) noexcept {}
        IToggleSplitButtonStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeView :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeView>
    {
        ITreeView(std::nullptr_t = nullptr) noexcept {}
        ITreeView(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeView2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeView2>
    {
        ITreeView2(std::nullptr_t = nullptr) noexcept {}
        ITreeView2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewCollapsedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewCollapsedEventArgs>
    {
        ITreeViewCollapsedEventArgs(std::nullptr_t = nullptr) noexcept {}
        ITreeViewCollapsedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewCollapsedEventArgs2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewCollapsedEventArgs2>
    {
        ITreeViewCollapsedEventArgs2(std::nullptr_t = nullptr) noexcept {}
        ITreeViewCollapsedEventArgs2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewDragItemsCompletedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewDragItemsCompletedEventArgs>
    {
        ITreeViewDragItemsCompletedEventArgs(std::nullptr_t = nullptr) noexcept {}
        ITreeViewDragItemsCompletedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewDragItemsCompletedEventArgs2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewDragItemsCompletedEventArgs2>
    {
        ITreeViewDragItemsCompletedEventArgs2(std::nullptr_t = nullptr) noexcept {}
        ITreeViewDragItemsCompletedEventArgs2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewDragItemsStartingEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewDragItemsStartingEventArgs>
    {
        ITreeViewDragItemsStartingEventArgs(std::nullptr_t = nullptr) noexcept {}
        ITreeViewDragItemsStartingEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewExpandingEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewExpandingEventArgs>
    {
        ITreeViewExpandingEventArgs(std::nullptr_t = nullptr) noexcept {}
        ITreeViewExpandingEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewExpandingEventArgs2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewExpandingEventArgs2>
    {
        ITreeViewExpandingEventArgs2(std::nullptr_t = nullptr) noexcept {}
        ITreeViewExpandingEventArgs2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewFactory>
    {
        ITreeViewFactory(std::nullptr_t = nullptr) noexcept {}
        ITreeViewFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewItem :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewItem>
    {
        ITreeViewItem(std::nullptr_t = nullptr) noexcept {}
        ITreeViewItem(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewItem2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewItem2>
    {
        ITreeViewItem2(std::nullptr_t = nullptr) noexcept {}
        ITreeViewItem2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewItemFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewItemFactory>
    {
        ITreeViewItemFactory(std::nullptr_t = nullptr) noexcept {}
        ITreeViewItemFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewItemInvokedEventArgs :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewItemInvokedEventArgs>
    {
        ITreeViewItemInvokedEventArgs(std::nullptr_t = nullptr) noexcept {}
        ITreeViewItemInvokedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewItemStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewItemStatics>
    {
        ITreeViewItemStatics(std::nullptr_t = nullptr) noexcept {}
        ITreeViewItemStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewItemStatics2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewItemStatics2>
    {
        ITreeViewItemStatics2(std::nullptr_t = nullptr) noexcept {}
        ITreeViewItemStatics2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewItemTemplateSettings :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewItemTemplateSettings>
    {
        ITreeViewItemTemplateSettings(std::nullptr_t = nullptr) noexcept {}
        ITreeViewItemTemplateSettings(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewItemTemplateSettingsFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewItemTemplateSettingsFactory>
    {
        ITreeViewItemTemplateSettingsFactory(std::nullptr_t = nullptr) noexcept {}
        ITreeViewItemTemplateSettingsFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewItemTemplateSettingsStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewItemTemplateSettingsStatics>
    {
        ITreeViewItemTemplateSettingsStatics(std::nullptr_t = nullptr) noexcept {}
        ITreeViewItemTemplateSettingsStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewList :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewList>
    {
        ITreeViewList(std::nullptr_t = nullptr) noexcept {}
        ITreeViewList(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewListFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewListFactory>
    {
        ITreeViewListFactory(std::nullptr_t = nullptr) noexcept {}
        ITreeViewListFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewNode :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewNode>
    {
        ITreeViewNode(std::nullptr_t = nullptr) noexcept {}
        ITreeViewNode(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewNodeFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewNodeFactory>
    {
        ITreeViewNodeFactory(std::nullptr_t = nullptr) noexcept {}
        ITreeViewNodeFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewNodeStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewNodeStatics>
    {
        ITreeViewNodeStatics(std::nullptr_t = nullptr) noexcept {}
        ITreeViewNodeStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewStatics>
    {
        ITreeViewStatics(std::nullptr_t = nullptr) noexcept {}
        ITreeViewStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITreeViewStatics2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITreeViewStatics2>
    {
        ITreeViewStatics2(std::nullptr_t = nullptr) noexcept {}
        ITreeViewStatics2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITwoPaneView :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITwoPaneView>
    {
        ITwoPaneView(std::nullptr_t = nullptr) noexcept {}
        ITwoPaneView(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITwoPaneViewFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITwoPaneViewFactory>
    {
        ITwoPaneViewFactory(std::nullptr_t = nullptr) noexcept {}
        ITwoPaneViewFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ITwoPaneViewStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ITwoPaneViewStatics>
    {
        ITwoPaneViewStatics(std::nullptr_t = nullptr) noexcept {}
        ITwoPaneViewStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IUniformGridLayout :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IUniformGridLayout>
    {
        IUniformGridLayout(std::nullptr_t = nullptr) noexcept {}
        IUniformGridLayout(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IUniformGridLayoutFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IUniformGridLayoutFactory>
    {
        IUniformGridLayoutFactory(std::nullptr_t = nullptr) noexcept {}
        IUniformGridLayoutFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IUniformGridLayoutStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IUniformGridLayoutStatics>
    {
        IUniformGridLayoutStatics(std::nullptr_t = nullptr) noexcept {}
        IUniformGridLayoutStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IVirtualizingLayout :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IVirtualizingLayout>
    {
        IVirtualizingLayout(std::nullptr_t = nullptr) noexcept {}
        IVirtualizingLayout(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IVirtualizingLayoutContext :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IVirtualizingLayoutContext>
    {
        IVirtualizingLayoutContext(std::nullptr_t = nullptr) noexcept {}
        IVirtualizingLayoutContext(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IVirtualizingLayoutContextFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IVirtualizingLayoutContextFactory>
    {
        IVirtualizingLayoutContextFactory(std::nullptr_t = nullptr) noexcept {}
        IVirtualizingLayoutContextFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IVirtualizingLayoutContextOverrides :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IVirtualizingLayoutContextOverrides>
    {
        IVirtualizingLayoutContextOverrides(std::nullptr_t = nullptr) noexcept {}
        IVirtualizingLayoutContextOverrides(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IVirtualizingLayoutFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IVirtualizingLayoutFactory>
    {
        IVirtualizingLayoutFactory(std::nullptr_t = nullptr) noexcept {}
        IVirtualizingLayoutFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IVirtualizingLayoutOverrides :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IVirtualizingLayoutOverrides>
    {
        IVirtualizingLayoutOverrides(std::nullptr_t = nullptr) noexcept {}
        IVirtualizingLayoutOverrides(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IWebView2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IWebView2>
    {
        IWebView2(std::nullptr_t = nullptr) noexcept {}
        IWebView2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IWebView2Factory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IWebView2Factory>
    {
        IWebView2Factory(std::nullptr_t = nullptr) noexcept {}
        IWebView2Factory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IWebView2Statics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IWebView2Statics>
    {
        IWebView2Statics(std::nullptr_t = nullptr) noexcept {}
        IWebView2Statics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IXamlControlsResources :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IXamlControlsResources>
    {
        IXamlControlsResources(std::nullptr_t = nullptr) noexcept {}
        IXamlControlsResources(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IXamlControlsResources3 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IXamlControlsResources3>
    {
        IXamlControlsResources3(std::nullptr_t = nullptr) noexcept {}
        IXamlControlsResources3(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IXamlControlsResourcesStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IXamlControlsResourcesStatics>
    {
        IXamlControlsResourcesStatics(std::nullptr_t = nullptr) noexcept {}
        IXamlControlsResourcesStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IXamlControlsResourcesStatics3 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IXamlControlsResourcesStatics3>
    {
        IXamlControlsResourcesStatics3(std::nullptr_t = nullptr) noexcept {}
        IXamlControlsResourcesStatics3(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
}
#endif
